@@ -23,15 +23,11 @@ import mimetypes
 import os
 import tempfile
 import time
-try:
-    from urlparse import urlsplit
-except ImportError:
-    from urllib.parse import urlsplit
+from urllib.parse import urlsplit
+from io import BytesIO
 
 from luigi.contrib import gcp
 import luigi.target
-from luigi import six
-from luigi.six.moves import xrange
 from luigi.format import FileWrapper
 
 logger = logging.getLogger('luigi-interface')
@@ -64,6 +60,9 @@ EVENTUAL_CONSISTENCY_SLEEP_INTERVAL = 0.1
 # Maximum number of sleeps for eventual consistency.
 EVENTUAL_CONSISTENCY_MAX_SLEEPS = 300
 
+# Uri for batch requests
+GCS_BATCH_URI = 'https://storage.googleapis.com/batch/storage/v1'
+
 
 def _wait_for_consistency(checker):
     """Eventual consistency: wait until GCS reports something is true.
@@ -71,7 +70,7 @@ def _wait_for_consistency(checker):
     This is necessary for e.g. create/delete where the operation might return,
     but won't be reflected for a bit.
     """
-    for _ in xrange(EVENTUAL_CONSISTENCY_MAX_SLEEPS):
+    for _ in range(EVENTUAL_CONSISTENCY_MAX_SLEEPS):
         if checker():
             return
 
@@ -235,7 +234,7 @@ class GCSClient(luigi.target.FileSystem):
                 raise InvalidDeleteException(
                     'Path {} is a directory. Must use recursive delete'.format(path))
 
-            req = http.BatchHttpRequest()
+            req = http.BatchHttpRequest(batch_uri=GCS_BATCH_URI)
             for it in self._list_iter(bucket, self._add_path_delimiter(obj)):
                 req.add(self.client.objects().delete(bucket=bucket, object=it['name']))
             req.execute()
@@ -285,10 +284,10 @@ class GCSClient(luigi.target.FileSystem):
 
     def put_string(self, contents, dest_path, mimetype=None):
         mimetype = mimetype or mimetypes.guess_type(dest_path)[0] or DEFAULT_MIMETYPE
-        assert isinstance(mimetype, six.string_types)
-        if not isinstance(contents, six.binary_type):
+        assert isinstance(mimetype, str)
+        if not isinstance(contents, bytes):
             contents = contents.encode("utf-8")
-        media = http.MediaIoBaseUpload(six.BytesIO(contents), mimetype, resumable=bool(contents))
+        media = http.MediaIoBaseUpload(BytesIO(contents), mimetype, resumable=bool(contents))
         self._do_put(media, dest_path)
 
     def mkdir(self, path, parents=True, raise_if_exists=False):
